@@ -119,6 +119,10 @@ def instructBegin(text, font = None, size = None, color = None, scroll = None, r
         # uf the justification is "center" center the texts between the margins...
         for line_text in line_texts:
             inst_lines.append((line_text, (leftmargin * inst_resy) + (inst_resx - (leftmargin + rightmargin) * inst_resy) / 2 - line_text.getSize()[0] / 2))
+    
+    # persistently load texts
+    for line_text in line_texts:
+        line_text.requireLoaded()
 
     # at start, the user has not seen all of the text
     inst_seenall = False
@@ -296,6 +300,10 @@ def instructEnd(exitbutton = None, clk = None):
 
     # unshow all drawn text
     inst_v.unshow(*inst_drawn)
+    
+    # allow texts to be unloaded
+    for line, leftpadding in inst_lines:
+        line.unrequireLoaded()
 
     # update the screen, noting the timestamp
     timestamp = inst_v.updateScreen()
@@ -761,7 +769,8 @@ def mathDistract(clk = None,
                  incorrectSndFile = None,
                  tfKeys = None,
                  ansMod = [0,1,-1,10,-10],
-                 ansProb = [.5,.125,.125,.125,.125]):
+                 ansProb = [.5,.125,.125,.125,.125],
+		 visualFeedback = False):
     """
     Math distractor for specified period of time.  Logs to a math_distract.log
     if no log is passed in.
@@ -790,7 +799,7 @@ def mathDistract(clk = None,
       tfKeys - Tuple of keys for true/false problems. e.g., tfKeys = ('T','F')
       ansMod - For True/False problems, the possible values to add to correct answer.
       ansProb - The probability of each modifer on ansMod (must add to 1).
-      
+      visualFeedback - Whether to provide visual feedback to indicate correctness.
     """
 
     # start the timing
@@ -846,6 +855,7 @@ def mathDistract(clk = None,
             pass
         ansProb = Numeric.cumsum(ansProb)
     else:
+	# not t/f problems 
         tfProblems = False
 
     # set up the answer button
@@ -929,7 +939,9 @@ def mathDistract(clk = None,
                 isCorrect = 0
         else:
             # is part of numeric answer
-            while kret and ((kret.name != "RETURN" and kret.name != "ENTER") or (hasMinus is True and len(rstr)<=1) or (len(rstr)==0)):
+            while kret and \
+                      ((kret.name != "RETURN" and kret.name != "ENTER") or \
+                       (hasMinus is True and len(rstr)<=1) or (len(rstr)==0)):
                 # process the response
                 if kret.name == 'BACKSPACE':
                     # remove last char
@@ -944,10 +956,10 @@ def mathDistract(clk = None,
                         hasMinus = True
                 elif kret.name == 'RETURN' or kret.name == 'ENTER':
                     # ignore cause have minus without number
-                    continue
+                    pass
                 elif len(rstr) == 0 and (kret.name == '0' or kret.name == '[0]'):
                     # Can't start a number with 0, so pass
-                    continue
+                    pass
                 else:
                     # if its a number, just append
                     numstr = kret.name.strip('[]')
@@ -965,16 +977,36 @@ def mathDistract(clk = None,
                 kret,timestamp = ans_but.waitWithTime(maxDuration = curProbTimeLimit,clock=clk)
 
             # check the answer
-            if len(rstr)==0 | eval(rstr) != cor_ans:
+            if len(rstr)==0 or eval(rstr) != cor_ans:
                 isCorrect = 0
             else:
                 isCorrect = 1
 
         # give feedback
         if isCorrect == 1:
-            correctBeep.present(clk)
+	    # play the beep
+            pTime = a.play(correctBeep,t=clk,doDelay=False)
+	    clk.tare(pTime[0])
+            #correctBeep.present(clk)
+
+	    # see if set color of text
+	    if visualFeedback: 
+		pt = v.replace(pt,display.Text(probtxt,size=textSize,color='green'))
+		rt = v.replace(rt,display.Text(rstr, size=textSize, color='green'))
+		v.updateScreen(clk)
+		clk.delay(correctBeepDur)
         else:
-            incorrectBeep.present(clk)
+	    # play the beep
+            pTime = a.play(incorrectBeep,t=clk,doDelay=False)
+	    clk.tare(pTime[0])
+            #incorrectBeep.present(clk)
+
+	    # see if set color of text
+	    if visualFeedback: 
+		pt = v.replace(pt,display.Text(probtxt,size=textSize,color='red'))
+		rt = v.replace(rt,display.Text(rstr, size=textSize, color='red'))
+		v.updateScreen(clk)
+		clk.delay(incorrectBeepDur)
         
         # calc the RT as (RT, maxlatency)
         prob_rt = (timestamp[0]-probstart[0],timestamp[1]+probstart[1])
@@ -986,7 +1018,7 @@ def mathDistract(clk = None,
                            probstart)
         
         # clear the problem
-        v.unshow(pt,rt)
+	v.unshow(pt,rt)
         v.updateScreen(clk)
         
         # increment the curprob
