@@ -50,26 +50,17 @@ class Showable:
     """
     An object which may be displayed in the basic video output layer.
     """
-    def smartShow(self, x, y):
-        """
-        Displays this showable on the screen.  If the showable is not
-        loaded, it loads, then shows, then unloads the object again.
-
-        INPUT ARGS:
-          x- x coordinate (in pixels) at which to draw the object
-          y- y coordinate (in pixels) at which to draw the object
-        """
-        if self.isLoaded():
-            # If we're loaded, just show
-            self.show(x, y)
-
-            # see if unload
-            if self.unloadAfterSmartShow():
-                self.unload()
-        else:
-            # otherwise, load, then show, then unload
+    def __init__(self):
+        self.loadRequireCount = 0
+    def requireLoaded(self):
+        self.loadRequireCount += 1
+        if not self.isLoaded():
             self.load()
-            self.show(x, y)
+    def unrequireLoaded(self):
+        self.loadRequireCount -= 1
+        if self.loadRequireCount < 0:
+            self.loadRequireCount = 0
+        if self.loadRequireCount == 0 and self.isLoaded():
             self.unload()
     def show(self, x, y):  # to be overridden
         """
@@ -92,7 +83,7 @@ class Showable:
         Returns true if the showable is loaded in memory, otherwise returns false.
         """
         return True
-    def load(self,keepLoadedAfterSmartShow=False):
+    def load(self):
         """
         Loads the object into memory.
         """
@@ -102,11 +93,7 @@ class Showable:
         Unloads the object from memory.
         """
         pass
-    def unloadAfterSmartShow(self):
-        """
-        See if should unload from memory after show.
-        """
-        return True
+
 class Shown:
     """
     Instances of this class are meant to act as unique identifiers for
@@ -116,26 +103,26 @@ class Shown:
     ...) for use in placing other showables.
     """
     def __init__(self, x, y, width, height):
-	"""
-	Create a shown object.
-	"""
-	# set up the values
-	self.x = x
-	self.y = y
-	self.width = width
-	self.height = height
+        """
+        Create a shown object.
+        """
+        # set up the values
+        self.x = x
+        self.y = y
+        self.width = width
+        self.height = height
 
-	# calculate the anchors
-	self.anchor = {}
-	self.anchor[CENTER] = (x + (width / 2), y - (height / 2))
-	self.anchor[NORTH] = (x + (width / 2), y - height)
-	self.anchor[NORTHEAST] = (x + width, y - height)
-	self.anchor[EAST] = (x + width, y - (height / 2))
-	self.anchor[SOUTHEAST] = (x + width, y)
-	self.anchor[SOUTH] = (x + (width / 2), y)
-	self.anchor[SOUTHWEST] = (x, y)
-	self.anchor[WEST] = (x, y - (height / 2))
-	self.anchor[NORTHWEST] = (x, y - height)
+        # calculate the anchors
+        self.anchor = {}
+        self.anchor[CENTER] = (x + (width / 2), y - (height / 2))
+        self.anchor[NORTH] = (x + (width / 2), y - height)
+        self.anchor[NORTHEAST] = (x + width, y - height)
+        self.anchor[EAST] = (x + width, y - (height / 2))
+        self.anchor[SOUTHEAST] = (x + width, y)
+        self.anchor[SOUTH] = (x + (width / 2), y)
+        self.anchor[SOUTHWEST] = (x, y)
+        self.anchor[WEST] = (x, y - (height / 2))
+        self.anchor[NORTHWEST] = (x, y - height)
 
 class ActiveShowable(Showable):
     """
@@ -163,6 +150,7 @@ class Image(UniquelyConstructed, Carvable, Showable, Stimulus):
         ...
         """
         Carvable.__init__(self)
+        Showable.__init__(self)
         
         # save the proportional dimensions...
         self.propxsize = propxsize
@@ -179,18 +167,9 @@ class Image(UniquelyConstructed, Carvable, Showable, Stimulus):
             self.img = None
             self.img_unscaled = None
 
-        # default to not preventing unload after smart show
-        self.preventUnloadAfterSmartShow = False
-
         # set empty logline
         self.logLineStr = 'IMAGE'
 
-    def unloadAfterSmartShow(self):
-        """
-        See if should unload after smartShow.
-        """
-        return not self.preventUnloadAfterSmartShow
-
     def getLow(self):
         """
         Returns the LowImage object associated with this Image.
@@ -217,7 +196,7 @@ class Image(UniquelyConstructed, Carvable, Showable, Stimulus):
         r = self.img_unscaled
         self.unload()
         return r
-    def load(self,keepLoadedAfterSmartShow=False):
+    def load(self):
         """
         After calling this method, the image data is gauranteed to be
         loaded into primary memory.
@@ -225,10 +204,6 @@ class Image(UniquelyConstructed, Carvable, Showable, Stimulus):
         If keepLoadedAfterSmartShow is set to True, the image will not
         be unloaded after it is shown with SmartShow.
         """
-        # make the load persistent
-        if keepLoadedAfterSmartShow:
-            self.preventUnloadAfterSmartShow = True
-            
         if not self.img:
             # if it's not already loaded, load it by constructing a LowImage object...
 
@@ -681,6 +656,8 @@ class Text(Showable, Stimulus):
         global defaultFont
         global defualtFontSize
         global defaultFontColor
+		
+        Showable.__init__(self)
         
         # split the text into lines
         self.text = text.split("\n")
@@ -702,15 +679,6 @@ class Text(Showable, Stimulus):
         # set the rendered text to None (not rendered)
         self.rendered = None
 
-        # default to not preventing unload after smart show
-        self.preventUnloadAfterSmartShow = False
-
-    def unloadAfterSmartShow(self):
-        """
-        See if should unload after smartShow.
-        """
-        return not self.preventUnloadAfterSmartShow
-
     def __getstate__(self):
         """
         Don't give the rendered form to pickle.
@@ -743,19 +711,15 @@ class Text(Showable, Stimulus):
         Delete all the rendered text.
         """
         self.rendered = []
-    def load(self,keepLoadedAfterSmartShow=False):
+    def load(self):
         """
-        Wrapper to render that processes persistent loads.
+        Wrapper to render.
         """
-        # make the load persistent
-        if keepLoadedAfterSmartShow:
-            self.preventUnloadAfterSmartShow = True
-
         self.render()
 
     def unload(self):
         """
-        Point to unrender.
+        Wrapper to unrender.
         """
         self.unrender()
 
@@ -1052,17 +1016,10 @@ class SolidBackground(Showable):  # change this to handle any rectangular region
         """
         Create SolidBackground object.
         """
+        Showable.__init__(self)
+        
         # save the color
         self.color = color
-
-        # default to preventing unload after smart show
-        self.preventUnloadAfterSmartShow = True
-
-    def unloadAfterSmartShow(self):
-        """
-        See if should unload after smartShow.
-        """
-        return not self.preventUnloadAfterSmartShow
  
     def show(self, x, y):
         """
@@ -1201,6 +1158,9 @@ class VideoTrack(textlog.LogTrack):
         """
         Draw a basic video element.
         """
+        # persistently load the showable
+        showable.requireLoaded()
+        
         # create a new Shown object to represent this instance of the showable on the screen
         shown = Shown(x,y,*showable.getSize())
 
@@ -1347,6 +1307,9 @@ class VideoTrack(textlog.LogTrack):
                     # decrement the active pending count, if the showable is active
                     self.activepending -= 1
                 
+                # allow showable to be unloaded
+                showable.unrequireLoaded()
+                
                 # append the index to the deletion list
                 deletes.append(n)
 
@@ -1423,10 +1386,11 @@ class VideoTrack(textlog.LogTrack):
         # iterate through the onscreen list...
         for shown, showable, x, y in self.onscreen:
             # ...showing everything in order
-            showable.smartShow(x, y)
+            showable.show(x, y)
 
         # update the screen at the calculated time
-        r = hardware.makeVideoChanges(t)
+	# now passes in self as a video track instance
+        r = hardware.makeVideoChanges(t,self)  
         
         for fnc, targs, dargs in self.do_after_update:
             # perform all waiting do_after_update calls
@@ -1479,10 +1443,10 @@ class VideoTrack(textlog.LogTrack):
             # iterate through the onscreen list...
             for shown, showable, x, y in self.onscreen:
                 # ...showing everything in order
-                showable.smartShow(x, y)
+                showable.show(x, y)
 
             # update the screen at the calculated time
-            self.last_updated = hardware.makeVideoChanges(t)
+            self.last_updated = hardware.makeVideoChanges(t,self)
 
             # log the contents of the display
             self.logDisplay(self.last_updated)
