@@ -926,6 +926,56 @@ class ButtonChooser(Chooser):
             self.choose(b, timestamp)
 ButtonChooser.__module__ = "pyepl.mechinput"  # cope with pyrex bug
 
+
+class FirstButtonChooser(Chooser):
+    """
+    This class represents a set of buttons.  It can be used to
+    determine which button, out of the set, has been pressed first,
+    but only after you have set the minimum start time (and optional
+    end time) via the setTimeRange method.
+
+    The primary use of this class is to set some buttons to watch
+    during the presentation of some stimuli.  Then you can easily
+    determine which button, if any was pressed first during the
+    specified time range.
+    """
+
+    def __init__(self, *buttons):
+        """
+        Constructs FirstButtonChooser from a list of possible Buttons and
+        other ButtonChoosers.
+        """
+        Chooser.__init__(self, *buttons)
+	self.minTime = None
+	self.maxTime = None
+        self.cb = MethodCallback(self.callback)
+        for n, b in enumerate(self):
+            b.addCallback(self.cb, n, b)
+    def setTimeRange(self,minTime,maxTime=None):
+	"""
+	Set the time range within which a button can be chosen.  
+
+	If maxTime is None, then a button can be chosen anytime
+	after the minTime.
+	"""
+	self.chosen = None
+	self.timestamp = None
+	self.minTime = minTime
+	self.maxTime = maxTime
+    def callback(self, pressed, timestamp, n, b):
+        """
+        Callback used to get information from buttons.
+        """
+	# only press if nothing pressed yet and beyond 
+	# earliest start time.
+        if pressed and \
+		self.chosen is None and \
+		not self.minTime is None and \
+		timestamp[0] >= self.minTime and \
+		(self.maxTime is None or timestamp[0] < self.maxTime):
+            self.choose(b, timestamp)
+FirstButtonChooser.__module__ = "pyepl.mechinput"  # cope with pyrex bug
+
 class AxisChooser(Chooser):
     """
     This class represents a set of axes.  It can be used to determine
