@@ -361,7 +361,7 @@ class FileAudioClip(MediaFile,AudioClip):
 		self.fileSettings['channels'] = sfile.getChannels()
 		nf = sfile.getFrames()
 		del sfile
-		if uname()[0]=='Darwin': # handle Mac endian-ness difference
+		if uname()[4].find('Power')>=0: # handle Mac endian-ness difference
 		    byteorder = '>'
 		else:
 		    byteorder = '<'
